PCB Environment: py::GIL_guard Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
py::GIL_guard Class Reference

The GIL. More...

`#include <Py.hpp>`

## Public Member Functions
| GIL_guard (GIL_guard &&moved) noexcept
GIL_guard & | operator= (GIL_guard &&moved) noexcept
| GIL_guard (const GIL_guard &)=delete

## Detailed Description

The GIL.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Py.hpp